# autohack-next

> English | [简体中文](./docs/README_zh.md)

A highly customizable competitive programming Hack tool written in Python.

A completely refactored version of [autohack](https://github.com/gi-b716/autohack) with clearer configuration, a redesigned interface, and more powerful performance.

## Installation

autohack-next is published as a package on PyPI. Install it using a Python package manager.

## Usage

Run the following command:

```bash
python -m autohack
```

or

```bash
autohack
```

On the first run, it will generate a `.autohack` folder in the current directory and exit.

After adjusting the settings in `.autohack/config.json`, run it again to start using.
